@@ -1,4 +1,19 @@
 #!/usr/bin/env python3
+# Copyright (C) 2022 John Dovern
+#
+# This file is part of loadconf <https://codeberg.org/johndovern/loadconf>.
+#
+# loadconf is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software
+# Foundation version 3 of the License
+#
+# loadconf is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# loadconf.  If not, see <http://www.gnu.org/licenses/>.
+
 import csv
 import json
 import os
@@ -10,20 +25,6 @@ from typing import Optional, Iterable, List, Dict
 
 
 class Config:
-    """
-    Initilization example:
-
-        >>> from loadconf import Config
-        >>> c = Config("my_program")
-        >>> c._program
-        'my_program'
-        >>> c._platform
-        'linux'
-        >>> print(c.config_dir)
-        None
-        >>> print(c.files)
-        None
-    """
 
     def __init__(
         self,
@@ -39,17 +40,15 @@ class Config:
         else:
             self._platform = "windows"
         self.config_dir = None
+        self.files = {}
+        self.settings = {}
+        self.stored = {}
 
     def create_files(
         self,
         create_files: List,
     ):
         """
-        Example usage:
-
-            >>> file_list = ["conf", "/path/to/file/to/create.txt"]
-            >>> c.create_files(file_list)
-
         Test if config files exist and create them if needed.
         """
         if self.config_dir is not None:
@@ -58,8 +57,8 @@ class Config:
                 dir.mkdir(parents=True, exist_ok=True)
         files = []
         for file in create_files:
-            if file in self.defined_files.keys():
-                files.append(self.defined_files[file])
+            if file in self.files.keys():
+                files.append(self.files[file])
             elif os.path.isabs(file):
                 files.append(file)
         for file in files:
@@ -73,32 +72,13 @@ class Config:
         config_dir: Optional[str] = None,
     ):
         """
-        Example usage:
-
-            >>> user_files = { "conf": "my_program.conf" }
-            >>> c.define_files(user_files)
-            >>> c.conf
-            '/home/user/.config/my_program/my_program.conf'     # on Linux
-            '/home/user/Library/Preferences/my_program.conf'    # on MacOS
-            'C:\\Users\\user\\AppData\\Local\\my_program.conf'  # on Windows
-            >>> c.defined_files # on Linux
-            {'conf': '/home/user/.config/my_program/my_program.conf'}
-
-        Why you might use this:
-
-        - Finds where config files should get installed by default
-        - Gives a quick way to access a file by it's key
-        - Allows for access via keys when calling other methods like:
-            - create_files()
-            - read_conf()
-            - store_files()
+        Define files and automatically find where they should go
         """
-        self.config_dir = None
         path = ""
         # If program wants to use it's own dir then ensure it exists
         if config_dir is not None and os.path.isdir(config_dir):
             self.config_dir = config_dir
-        # Else define the locations where config files should be stored
+        # Else define the locations where config files should get stored
         elif self._platform == "linux":
             path = os.getenv("XDG_CONFIG_HOME", os.path.expanduser("~/.config"))
         elif self._platform == "macos":
@@ -108,26 +88,20 @@ class Config:
             path = f"C:\\Users\\{user_name}\\AppData\\Local"
         if not self.config_dir:
             self.config_dir = os.path.join(path, self._program)
-        self.defined_files = {}
         for key, value in user_files.items():
             file = os.path.join(self.config_dir, value)
-            self.defined_files[key] = file
-            setattr(self, key, file)
+            self.files[key] = file
 
     def define_settings(
         self,
         settings: Dict,
     ):
         """
-        Example usage:
-
-            <<define_files_ex>>
-
         Users may not provide all settings that are relevant to your program.
         If you want to set some defaults, this makes it easy.
         """
         for key, value in settings.items():
-            setattr(self, key, value)
+            self.settings[key] = value
 
     def read_conf(
         self,
@@ -137,47 +111,13 @@ class Config:
         comment_char: str = "#",
     ):
         """
-        Example conf file:
-
-            # my_program.conf
-            setting_name = setting value
-            fav_color = Blue
-            int_val = 10
-            bool_val = true
-            good_line = My value with escaped delimiter \\= good time
-
-        Example usage:
-
-            >>> settings = ["fav_color", "good_line", "int_val", "bool_val"]
-            >>> files = ["conf"]
-            >>> c.read_conf(settings, files)
-            >>> c.good_line
-            'My value with escaped delimiter = good time'
-            >>> c.fav_color
-            'Blue'
-            >>> c.bool_val
-            True
-            >>> c.int_val
-            10
-
-        Things to note:
-
-            - read_conf() will make effort to determine int and bool values
-              for settings instead of storing everything as a string.
-            - If the user has a value that has an unescaped delimiter then csv.Error will
-              get raised with a note about the line number that caused the error.
-            - The default delimiter is the equal sign "=" but you can set something
-              different
-            - The default comment character is pound "#" but you can set it to something
-              different
-            - For users to escape the delimiter character they can use a backslash. That
-              backslash will not get included in the stored value.
+        Read a config file
         """
         files = []
         # File may be an actual file or a key value from defined_files
         for file in read_files:
-            if hasattr(self, "defined_files") and file in self.defined_files.keys():
-                files.append(self.defined_files[file])
+            if self.files:
+                files.append(self.files[file])
             elif os.path.isfile(file):
                 files.append(file)
         # Regex object for subbing delimiter
@@ -217,42 +157,15 @@ class Config:
                         pass
                     # Ignore user defined settings that program doesn't care about
                     if setting_name in user_settings:
-                        setattr(self, setting_name, setting_value)
-
-    def store_args(
-        self,
-        user_args: ArgumentParser,
-    ):
-        """
-        This module aims to make cli style packages more flexible. As a convenience,
-        you can store an ~ArgumentParser~ object under ~c.args~.
-        """
-        self.args = user_args
+                        self.settings[setting_name] = setting_value
 
     def store_files(
         self,
         files: Iterable,
-        dict_name: str = "stored",
         json_file: bool = False,
     ):
         """
-        Example usage:
-
-            <<store_files_ex>>
-
-        The purpose of this method is to allow you to store each line of a file in a
-        list accessible through c.stored["key"]. Why might you want this? Instead of
-        forcing a brittle syntax on the user you can give them an entire file to work
-        with. If a variable is useful as a list then this gives users an easy way to
-        define that list.
-
-        If you've run c.define_files() then you can give c.store_files() a list of
-        keys that correspond to a defined file. If you haven't defined any files then
-        you can give a dict of files to store and a key to store them under.
-
-        Storing json data can be nice too though:
-
-            <<store_json_ex>>
+        Store an entire file line by line in a list or load a json file.
         """
         # Temp dict to store at self.dict_name
         temp_dict = {}
@@ -262,7 +175,7 @@ class Config:
             read_files = files.values()
         # If user didn't give a dict ensure they have run define_files()
         elif hasattr(self, "defined_files"):
-            read_dict = self.defined_files
+            read_dict = self.files
             read_files = files
         # User has passed a list that does not have any meaning
         else:
@@ -274,7 +187,7 @@ class Config:
             if not key in read_files:
                 continue
             if json_file:
-                with open(file, "r") as data:
+                with open(file, 'r') as data:
                     jdata = json.load(data)
                 setattr(self, key, jdata)
                 temp_dict[key] = jdata
@@ -283,4 +196,4 @@ class Config:
                     temp_dict[key] = []
                     for line in f:
                         temp_dict[key].append(line.rstrip())
-        setattr(self, dict_name, temp_dict)
+        self.stored.update(temp_dict)
